"""Constants that are useful when working with OCR files."""
from typing import List

__all__: List[str] = ['NETS_ID']


#: Nets' data sender/recipient ID.
NETS_ID = '00008080'
